@@ -11,5 +11,7 @@ class TosterCommand(Command):
             self.fixtures = fixtures
 
         def __call__(self, args):
+            self.app.factory.run_module('tests')
+            self.app.factory.run_module_without_errors('tests')
             sys.argv.pop(0)
             TestRunner(self.app, self.fixtures)()
